@@ -9,6 +9,17 @@ kDefaultGenerator = 'nevergrad'
 kDefaultMetric = 'loss'
 kDefaultMode = 'min'
 
+class NpEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        elif isinstance(obj, np.floating):
+            return float(obj)
+        elif isinstance(obj, np.ndarray):
+            return obj.tolist()
+        else:
+            return super(NpEncoder, self).default(obj)
+
 class SteeringIDDS():
     def __init__(self, parse=True):
         if (len(sys.argv) > 1) and parse:
@@ -78,7 +89,7 @@ class SteeringIDDS():
         return True
 
     def parse_idds_input(self, file):
-        if file is None:
+        if not file:
             return None, None, None
         points = []
         results = []
@@ -90,7 +101,7 @@ class SteeringIDDS():
         
         input_data = idds_data['points']
         for data in input_data:
-            if data[1] is not None:
+            if data[1]:
                 points.append(data[0])
                 results.append(data[1])
 
@@ -141,6 +152,6 @@ class SteeringIDDS():
         # save output
         if outfile:
             with open(outfile, 'w') as out:
-                json.dump(new_points, out, indent=2)
+                json.dump(new_points, out, indent=2, cls=NpEncoder)
 
 
